#!/bin/sh

usage() { 
	echo "Renumber backup repository to make it compatible for rsback-0.6.x"
	echo "Use this script only when upgrading from rsback prior to version 0.6.0"
	echo "hjb -- 2007-07-28"
	echo 
	echo "Usage: $0 archive-label max-num"
	echo "  archive-label   Name of the archive sets without suffix (e.g. 'backup' or 'daily')"
	echo "  max-num         Number of oldest archive"
	echo "                  The complete names of the archives will be composed of"
	echo "                  <achive-label>.<n> with n = 0 ... max-num"
}

ARCHIVE=$1
NUM_ARCHIVES=$2

if [ "$ARCHIVE" == "-h" ]; then
	usage
	exit
fi

if [ "x$ARCHIVE" == "x" ] || [ "x$NUM_ARCHIVES" == "x" ]; then
	echo "ERROR - missing or wrong paramter(s)."
	usage
	exit;
fi

# check repository before action

i=$NUM_ARCHIVES
while [ $i -ge 0 ]; do
	echo "Checking archive $ARCHIVE.$i"
	if [ -d $ARCHIVE.$i ]; then
		if [ $i == $NUM_ARCHIVES ] && [ -d $ARCHIVE.$(($i+1)) ]; then
			echo "*** Cannot move $ARCHIVE.$i to $ARCHIVE.$(($i+1)), $ARCHIVE.$(($i+1)) already exists."
			exit 1
		fi
	else
		echo "*** Directory $ARCHIVE.$i not found."
		if [ $i == 0 ]; then
			echo "Be sure not to apply this script twice." 
		fi
		exit 1
	fi
	i=$(($i-1))
done

# action
i=$NUM_ARCHIVES
while [ $i -ge 0 ]; do
	echo "Moving $ARCHIVE.$i to $ARCHIVE.$(($i+1))"
	mv -f $ARCHIVE.$i $ARCHIVE.$(($i+1))
	i=$(($i-1))
done

if [ -w history.$ARCHIVE ]; then
    echo "Deleting history.$ARCHIVE, rsback will be rebuild it."
    rm -f history.$ARCHIVE
fi
echo "ok"
echo
echo "Remember to increase the number of archives in your configuration file(s) by one,"
echo "if you want to keep the same number of archives as before"
echo "To do that, replace the lines like"
echo "  rotate = $ARCHIVE $NUM_ARCHIVES"
echo "by"
echo "  rotate = $ARCHIVE $(($NUM_ARCHIVES+1))"
echo "in the corresponding sections of your configuration file(s)."